# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: action.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import device_pb2 as device__pb2
from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='action.proto',
  package='action',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.actionP\001Z\026biostar/service/action'),
  serialized_pb=_b('\n\x0c\x61\x63tion.proto\x12\x06\x61\x63tion\x1a\x0c\x64\x65vice.proto\x1a\terr.proto\"!\n\x0c\x45ventTrigger\x12\x11\n\teventCode\x18\x01 \x01(\r\"j\n\x0cInputTrigger\x12\x0c\n\x04port\x18\x01 \x01(\r\x12&\n\nswitchType\x18\x02 \x01(\x0e\x32\x12.device.SwitchType\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x12\n\nscheduleID\x18\x04 \x01(\r\"P\n\x0fScheduleTrigger\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.action.ScheduleTriggerType\x12\x12\n\nscheduleID\x18\x02 \x01(\r\"\xb3\x01\n\x07Trigger\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.action.TriggerType\x12#\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x14.action.EventTrigger\x12#\n\x05input\x18\x04 \x01(\x0b\x32\x14.action.InputTrigger\x12)\n\x08schedule\x18\x05 \x01(\x0b\x32\x17.action.ScheduleTrigger\"a\n\x06Signal\x12\x10\n\x08signalID\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x12\n\nonDuration\x18\x03 \x01(\r\x12\x13\n\x0boffDuration\x18\x04 \x01(\r\x12\r\n\x05\x64\x65lay\x18\x05 \x01(\r\"E\n\x10OutputPortAction\x12\x11\n\tportIndex\x18\x01 \x01(\r\x12\x1e\n\x06signal\x18\x02 \x01(\x0b\x32\x0e.action.Signal\"A\n\x0bRelayAction\x12\x12\n\nrelayIndex\x18\x01 \x01(\r\x12\x1e\n\x06signal\x18\x02 \x01(\x0b\x32\x0e.action.Signal\"M\n\tLEDSignal\x12\x1f\n\x05\x63olor\x18\x01 \x01(\x0e\x32\x10.device.LEDColor\x12\x10\n\x08\x64uration\x18\x02 \x01(\r\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\r\"/\n\tLEDAction\x12\"\n\x07signals\x18\x01 \x03(\x0b\x32\x11.action.LEDSignal\"b\n\x0c\x42uzzerSignal\x12 \n\x04tone\x18\x01 \x01(\x0e\x32\x12.device.BuzzerTone\x12\x0f\n\x07\x66\x61\x64\x65out\x18\x02 \x01(\x08\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\r\n\x05\x64\x65lay\x18\x04 \x01(\r\"5\n\x0c\x42uzzerAction\x12%\n\x07signals\x18\x01 \x03(\x0b\x32\x14.action.BuzzerSignal\"H\n\rDisplayAction\x12\x10\n\x08\x64uration\x18\x01 \x01(\r\x12\x11\n\tdisplayID\x18\x02 \x01(\r\x12\x12\n\nresourceID\x18\x03 \x01(\r\"?\n\x0bSoundAction\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x12\n\nsoundIndex\x18\x02 \x01(\r\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\r\"B\n\nLiftAction\x12\x0e\n\x06liftID\x18\x01 \x01(\r\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.action.LiftActionType\"\xf5\x02\n\x06\x41\x63tion\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.action.ActionType\x12\"\n\x08stopFlag\x18\x03 \x01(\x0e\x32\x10.action.StopFlag\x12\r\n\x05\x64\x65lay\x18\x04 \x01(\r\x12\"\n\x05relay\x18\x05 \x01(\x0b\x32\x13.action.RelayAction\x12,\n\noutputPort\x18\x06 \x01(\x0b\x32\x18.action.OutputPortAction\x12&\n\x07\x64isplay\x18\x07 \x01(\x0b\x32\x15.action.DisplayAction\x12\"\n\x05sound\x18\x08 \x01(\x0b\x32\x13.action.SoundAction\x12\x1e\n\x03LED\x18\t \x01(\x0b\x32\x11.action.LEDAction\x12$\n\x06\x62uzzer\x18\n \x01(\x0b\x32\x14.action.BuzzerAction\x12 \n\x04lift\x18\x0b \x01(\x0b\x32\x12.action.LiftAction\"\xab\x01\n\x13TriggerActionConfig\x12\x41\n\x0etriggerActions\x18\x01 \x03(\x0b\x32).action.TriggerActionConfig.TriggerAction\x1aQ\n\rTriggerAction\x12 \n\x07trigger\x18\x01 \x01(\x0b\x32\x0f.action.Trigger\x12\x1e\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x0e.action.Action\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"@\n\x11GetConfigResponse\x12+\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1b.action.TriggerActionConfig\"Q\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.action.TriggerActionConfig\"\x13\n\x11SetConfigResponse\"W\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.action.TriggerActionConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*[\n\x0bTriggerType\x12\x10\n\x0cTRIGGER_NONE\x10\x00\x12\x11\n\rTRIGGER_EVENT\x10\x01\x12\x11\n\rTRIGGER_INPUT\x10\x02\x12\x14\n\x10TRIGGER_SCHEDULE\x10\x03*Q\n\x13ScheduleTriggerType\x12\x1d\n\x19SCHEDULE_TRIGGER_ON_START\x10\x00\x12\x1b\n\x17SCHEDULE_TRIGGER_ON_END\x10\x01*\xe5\x02\n\nActionType\x12\x0f\n\x0b\x41\x43TION_NONE\x10\x00\x12\x16\n\x12\x41\x43TION_LOCK_DEVICE\x10\x01\x12\x18\n\x14\x41\x43TION_UNLOCK_DEVICE\x10\x02\x12\x18\n\x14\x41\x43TION_REBOOT_DEVICE\x10\x03\x12\x18\n\x14\x41\x43TION_RELEASE_ALARM\x10\x04\x12\x18\n\x14\x41\x43TION_GENERAL_INPUT\x10\x05\x12\x10\n\x0c\x41\x43TION_RELAY\x10\x06\x12\x0e\n\nACTION_TTL\x10\x07\x12\x10\n\x0c\x41\x43TION_SOUND\x10\x08\x12\x12\n\x0e\x41\x43TION_DISPLAY\x10\t\x12\x11\n\rACTION_BUZZER\x10\n\x12\x0e\n\nACTION_LED\x10\x0b\x12\x1b\n\x17\x41\x43TION_FIRE_ALARM_INPUT\x10\x0c\x12\x17\n\x13\x41\x43TION_AUTH_SUCCESS\x10\r\x12\x14\n\x10\x41\x43TION_AUTH_FAIL\x10\x0e\x12\x0f\n\x0b\x41\x43TION_LIFT\x10\x0f*N\n\x08StopFlag\x12\r\n\tSTOP_NONE\x10\x00\x12\x17\n\x13STOP_ON_DOOR_CLOSED\x10\x01\x12\x1a\n\x16STOP_BY_CMD_RUN_ACTION\x10\x02*t\n\x0eLiftActionType\x12\x1f\n\x1bLIFT_ACTION_ACTIVATE_FLOORS\x10\x00\x12!\n\x1dLIFT_ACTION_DEACTIVATE_FLOORS\x10\x01\x12\x1e\n\x1aLIFT_ACTION_RELEASE_FLOORS\x10\x02\x32\xe4\x01\n\rTriggerAction\x12@\n\tGetConfig\x12\x18.action.GetConfigRequest\x1a\x19.action.GetConfigResponse\x12@\n\tSetConfig\x12\x18.action.SetConfigRequest\x1a\x19.action.SetConfigResponse\x12O\n\x0eSetConfigMulti\x12\x1d.action.SetConfigMultiRequest\x1a\x1e.action.SetConfigMultiResponseB5\n\x19\x63om.supremainc.sdk.actionP\x01Z\x16\x62iostar/service/actionb\x06proto3')
  ,
  dependencies=[device__pb2.DESCRIPTOR,err__pb2.DESCRIPTOR,])

_TRIGGERTYPE = _descriptor.EnumDescriptor(
  name='TriggerType',
  full_name='action.TriggerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRIGGER_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIGGER_EVENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIGGER_INPUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIGGER_SCHEDULE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2098,
  serialized_end=2189,
)
_sym_db.RegisterEnumDescriptor(_TRIGGERTYPE)

TriggerType = enum_type_wrapper.EnumTypeWrapper(_TRIGGERTYPE)
_SCHEDULETRIGGERTYPE = _descriptor.EnumDescriptor(
  name='ScheduleTriggerType',
  full_name='action.ScheduleTriggerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEDULE_TRIGGER_ON_START', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULE_TRIGGER_ON_END', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2191,
  serialized_end=2272,
)
_sym_db.RegisterEnumDescriptor(_SCHEDULETRIGGERTYPE)

ScheduleTriggerType = enum_type_wrapper.EnumTypeWrapper(_SCHEDULETRIGGERTYPE)
_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='action.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_LOCK_DEVICE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNLOCK_DEVICE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REBOOT_DEVICE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_RELEASE_ALARM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_GENERAL_INPUT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_RELAY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_TTL', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_SOUND', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_DISPLAY', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_BUZZER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_LED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_FIRE_ALARM_INPUT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_AUTH_SUCCESS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_AUTH_FAIL', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_LIFT', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2275,
  serialized_end=2632,
)
_sym_db.RegisterEnumDescriptor(_ACTIONTYPE)

ActionType = enum_type_wrapper.EnumTypeWrapper(_ACTIONTYPE)
_STOPFLAG = _descriptor.EnumDescriptor(
  name='StopFlag',
  full_name='action.StopFlag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOP_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP_ON_DOOR_CLOSED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP_BY_CMD_RUN_ACTION', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2634,
  serialized_end=2712,
)
_sym_db.RegisterEnumDescriptor(_STOPFLAG)

StopFlag = enum_type_wrapper.EnumTypeWrapper(_STOPFLAG)
_LIFTACTIONTYPE = _descriptor.EnumDescriptor(
  name='LiftActionType',
  full_name='action.LiftActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LIFT_ACTION_ACTIVATE_FLOORS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIFT_ACTION_DEACTIVATE_FLOORS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIFT_ACTION_RELEASE_FLOORS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2714,
  serialized_end=2830,
)
_sym_db.RegisterEnumDescriptor(_LIFTACTIONTYPE)

LiftActionType = enum_type_wrapper.EnumTypeWrapper(_LIFTACTIONTYPE)
TRIGGER_NONE = 0
TRIGGER_EVENT = 1
TRIGGER_INPUT = 2
TRIGGER_SCHEDULE = 3
SCHEDULE_TRIGGER_ON_START = 0
SCHEDULE_TRIGGER_ON_END = 1
ACTION_NONE = 0
ACTION_LOCK_DEVICE = 1
ACTION_UNLOCK_DEVICE = 2
ACTION_REBOOT_DEVICE = 3
ACTION_RELEASE_ALARM = 4
ACTION_GENERAL_INPUT = 5
ACTION_RELAY = 6
ACTION_TTL = 7
ACTION_SOUND = 8
ACTION_DISPLAY = 9
ACTION_BUZZER = 10
ACTION_LED = 11
ACTION_FIRE_ALARM_INPUT = 12
ACTION_AUTH_SUCCESS = 13
ACTION_AUTH_FAIL = 14
ACTION_LIFT = 15
STOP_NONE = 0
STOP_ON_DOOR_CLOSED = 1
STOP_BY_CMD_RUN_ACTION = 2
LIFT_ACTION_ACTIVATE_FLOORS = 0
LIFT_ACTION_DEACTIVATE_FLOORS = 1
LIFT_ACTION_RELEASE_FLOORS = 2



_EVENTTRIGGER = _descriptor.Descriptor(
  name='EventTrigger',
  full_name='action.EventTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='action.EventTrigger.eventCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=82,
)


_INPUTTRIGGER = _descriptor.Descriptor(
  name='InputTrigger',
  full_name='action.InputTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='action.InputTrigger.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='switchType', full_name='action.InputTrigger.switchType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='action.InputTrigger.duration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleID', full_name='action.InputTrigger.scheduleID', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=190,
)


_SCHEDULETRIGGER = _descriptor.Descriptor(
  name='ScheduleTrigger',
  full_name='action.ScheduleTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='action.ScheduleTrigger.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleID', full_name='action.ScheduleTrigger.scheduleID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=272,
)


_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='action.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='action.Trigger.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='action.Trigger.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='action.Trigger.event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='action.Trigger.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='action.Trigger.schedule', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=454,
)


_SIGNAL = _descriptor.Descriptor(
  name='Signal',
  full_name='action.Signal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signalID', full_name='action.Signal.signalID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='action.Signal.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onDuration', full_name='action.Signal.onDuration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offDuration', full_name='action.Signal.offDuration', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='action.Signal.delay', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=553,
)


_OUTPUTPORTACTION = _descriptor.Descriptor(
  name='OutputPortAction',
  full_name='action.OutputPortAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='portIndex', full_name='action.OutputPortAction.portIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signal', full_name='action.OutputPortAction.signal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=624,
)


_RELAYACTION = _descriptor.Descriptor(
  name='RelayAction',
  full_name='action.RelayAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayIndex', full_name='action.RelayAction.relayIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signal', full_name='action.RelayAction.signal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=691,
)


_LEDSIGNAL = _descriptor.Descriptor(
  name='LEDSignal',
  full_name='action.LEDSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='action.LEDSignal.color', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='action.LEDSignal.duration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='action.LEDSignal.delay', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=770,
)


_LEDACTION = _descriptor.Descriptor(
  name='LEDAction',
  full_name='action.LEDAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='action.LEDAction.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=772,
  serialized_end=819,
)


_BUZZERSIGNAL = _descriptor.Descriptor(
  name='BuzzerSignal',
  full_name='action.BuzzerSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tone', full_name='action.BuzzerSignal.tone', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fadeout', full_name='action.BuzzerSignal.fadeout', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='action.BuzzerSignal.duration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='action.BuzzerSignal.delay', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=919,
)


_BUZZERACTION = _descriptor.Descriptor(
  name='BuzzerAction',
  full_name='action.BuzzerAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='action.BuzzerAction.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=921,
  serialized_end=974,
)


_DISPLAYACTION = _descriptor.Descriptor(
  name='DisplayAction',
  full_name='action.DisplayAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='action.DisplayAction.duration', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayID', full_name='action.DisplayAction.displayID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resourceID', full_name='action.DisplayAction.resourceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1048,
)


_SOUNDACTION = _descriptor.Descriptor(
  name='SoundAction',
  full_name='action.SoundAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='action.SoundAction.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soundIndex', full_name='action.SoundAction.soundIndex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='action.SoundAction.delay', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1113,
)


_LIFTACTION = _descriptor.Descriptor(
  name='LiftAction',
  full_name='action.LiftAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='liftID', full_name='action.LiftAction.liftID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='action.LiftAction.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1115,
  serialized_end=1181,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='action.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='action.Action.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='action.Action.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stopFlag', full_name='action.Action.stopFlag', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='action.Action.delay', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relay', full_name='action.Action.relay', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputPort', full_name='action.Action.outputPort', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display', full_name='action.Action.display', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sound', full_name='action.Action.sound', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LED', full_name='action.Action.LED', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buzzer', full_name='action.Action.buzzer', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lift', full_name='action.Action.lift', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1557,
)


_TRIGGERACTIONCONFIG_TRIGGERACTION = _descriptor.Descriptor(
  name='TriggerAction',
  full_name='action.TriggerActionConfig.TriggerAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger', full_name='action.TriggerActionConfig.TriggerAction.trigger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='action.TriggerActionConfig.TriggerAction.action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1650,
  serialized_end=1731,
)

_TRIGGERACTIONCONFIG = _descriptor.Descriptor(
  name='TriggerActionConfig',
  full_name='action.TriggerActionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='triggerActions', full_name='action.TriggerActionConfig.triggerActions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRIGGERACTIONCONFIG_TRIGGERACTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1560,
  serialized_end=1731,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='action.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='action.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1769,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='action.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='action.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1771,
  serialized_end=1835,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='action.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='action.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='action.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1837,
  serialized_end=1918,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='action.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1920,
  serialized_end=1939,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='action.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='action.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='action.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1941,
  serialized_end=2028,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='action.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='action.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2030,
  serialized_end=2096,
)

_INPUTTRIGGER.fields_by_name['switchType'].enum_type = device__pb2._SWITCHTYPE
_SCHEDULETRIGGER.fields_by_name['type'].enum_type = _SCHEDULETRIGGERTYPE
_TRIGGER.fields_by_name['type'].enum_type = _TRIGGERTYPE
_TRIGGER.fields_by_name['event'].message_type = _EVENTTRIGGER
_TRIGGER.fields_by_name['input'].message_type = _INPUTTRIGGER
_TRIGGER.fields_by_name['schedule'].message_type = _SCHEDULETRIGGER
_OUTPUTPORTACTION.fields_by_name['signal'].message_type = _SIGNAL
_RELAYACTION.fields_by_name['signal'].message_type = _SIGNAL
_LEDSIGNAL.fields_by_name['color'].enum_type = device__pb2._LEDCOLOR
_LEDACTION.fields_by_name['signals'].message_type = _LEDSIGNAL
_BUZZERSIGNAL.fields_by_name['tone'].enum_type = device__pb2._BUZZERTONE
_BUZZERACTION.fields_by_name['signals'].message_type = _BUZZERSIGNAL
_LIFTACTION.fields_by_name['type'].enum_type = _LIFTACTIONTYPE
_ACTION.fields_by_name['type'].enum_type = _ACTIONTYPE
_ACTION.fields_by_name['stopFlag'].enum_type = _STOPFLAG
_ACTION.fields_by_name['relay'].message_type = _RELAYACTION
_ACTION.fields_by_name['outputPort'].message_type = _OUTPUTPORTACTION
_ACTION.fields_by_name['display'].message_type = _DISPLAYACTION
_ACTION.fields_by_name['sound'].message_type = _SOUNDACTION
_ACTION.fields_by_name['LED'].message_type = _LEDACTION
_ACTION.fields_by_name['buzzer'].message_type = _BUZZERACTION
_ACTION.fields_by_name['lift'].message_type = _LIFTACTION
_TRIGGERACTIONCONFIG_TRIGGERACTION.fields_by_name['trigger'].message_type = _TRIGGER
_TRIGGERACTIONCONFIG_TRIGGERACTION.fields_by_name['action'].message_type = _ACTION
_TRIGGERACTIONCONFIG_TRIGGERACTION.containing_type = _TRIGGERACTIONCONFIG
_TRIGGERACTIONCONFIG.fields_by_name['triggerActions'].message_type = _TRIGGERACTIONCONFIG_TRIGGERACTION
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _TRIGGERACTIONCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _TRIGGERACTIONCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _TRIGGERACTIONCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['EventTrigger'] = _EVENTTRIGGER
DESCRIPTOR.message_types_by_name['InputTrigger'] = _INPUTTRIGGER
DESCRIPTOR.message_types_by_name['ScheduleTrigger'] = _SCHEDULETRIGGER
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['Signal'] = _SIGNAL
DESCRIPTOR.message_types_by_name['OutputPortAction'] = _OUTPUTPORTACTION
DESCRIPTOR.message_types_by_name['RelayAction'] = _RELAYACTION
DESCRIPTOR.message_types_by_name['LEDSignal'] = _LEDSIGNAL
DESCRIPTOR.message_types_by_name['LEDAction'] = _LEDACTION
DESCRIPTOR.message_types_by_name['BuzzerSignal'] = _BUZZERSIGNAL
DESCRIPTOR.message_types_by_name['BuzzerAction'] = _BUZZERACTION
DESCRIPTOR.message_types_by_name['DisplayAction'] = _DISPLAYACTION
DESCRIPTOR.message_types_by_name['SoundAction'] = _SOUNDACTION
DESCRIPTOR.message_types_by_name['LiftAction'] = _LIFTACTION
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['TriggerActionConfig'] = _TRIGGERACTIONCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['TriggerType'] = _TRIGGERTYPE
DESCRIPTOR.enum_types_by_name['ScheduleTriggerType'] = _SCHEDULETRIGGERTYPE
DESCRIPTOR.enum_types_by_name['ActionType'] = _ACTIONTYPE
DESCRIPTOR.enum_types_by_name['StopFlag'] = _STOPFLAG
DESCRIPTOR.enum_types_by_name['LiftActionType'] = _LIFTACTIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventTrigger = _reflection.GeneratedProtocolMessageType('EventTrigger', (_message.Message,), dict(
  DESCRIPTOR = _EVENTTRIGGER,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.EventTrigger)
  ))
_sym_db.RegisterMessage(EventTrigger)

InputTrigger = _reflection.GeneratedProtocolMessageType('InputTrigger', (_message.Message,), dict(
  DESCRIPTOR = _INPUTTRIGGER,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.InputTrigger)
  ))
_sym_db.RegisterMessage(InputTrigger)

ScheduleTrigger = _reflection.GeneratedProtocolMessageType('ScheduleTrigger', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULETRIGGER,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.ScheduleTrigger)
  ))
_sym_db.RegisterMessage(ScheduleTrigger)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), dict(
  DESCRIPTOR = _TRIGGER,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.Trigger)
  ))
_sym_db.RegisterMessage(Trigger)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), dict(
  DESCRIPTOR = _SIGNAL,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.Signal)
  ))
_sym_db.RegisterMessage(Signal)

OutputPortAction = _reflection.GeneratedProtocolMessageType('OutputPortAction', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUTPORTACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.OutputPortAction)
  ))
_sym_db.RegisterMessage(OutputPortAction)

RelayAction = _reflection.GeneratedProtocolMessageType('RelayAction', (_message.Message,), dict(
  DESCRIPTOR = _RELAYACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.RelayAction)
  ))
_sym_db.RegisterMessage(RelayAction)

LEDSignal = _reflection.GeneratedProtocolMessageType('LEDSignal', (_message.Message,), dict(
  DESCRIPTOR = _LEDSIGNAL,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.LEDSignal)
  ))
_sym_db.RegisterMessage(LEDSignal)

LEDAction = _reflection.GeneratedProtocolMessageType('LEDAction', (_message.Message,), dict(
  DESCRIPTOR = _LEDACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.LEDAction)
  ))
_sym_db.RegisterMessage(LEDAction)

BuzzerSignal = _reflection.GeneratedProtocolMessageType('BuzzerSignal', (_message.Message,), dict(
  DESCRIPTOR = _BUZZERSIGNAL,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.BuzzerSignal)
  ))
_sym_db.RegisterMessage(BuzzerSignal)

BuzzerAction = _reflection.GeneratedProtocolMessageType('BuzzerAction', (_message.Message,), dict(
  DESCRIPTOR = _BUZZERACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.BuzzerAction)
  ))
_sym_db.RegisterMessage(BuzzerAction)

DisplayAction = _reflection.GeneratedProtocolMessageType('DisplayAction', (_message.Message,), dict(
  DESCRIPTOR = _DISPLAYACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.DisplayAction)
  ))
_sym_db.RegisterMessage(DisplayAction)

SoundAction = _reflection.GeneratedProtocolMessageType('SoundAction', (_message.Message,), dict(
  DESCRIPTOR = _SOUNDACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.SoundAction)
  ))
_sym_db.RegisterMessage(SoundAction)

LiftAction = _reflection.GeneratedProtocolMessageType('LiftAction', (_message.Message,), dict(
  DESCRIPTOR = _LIFTACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.LiftAction)
  ))
_sym_db.RegisterMessage(LiftAction)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), dict(
  DESCRIPTOR = _ACTION,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.Action)
  ))
_sym_db.RegisterMessage(Action)

TriggerActionConfig = _reflection.GeneratedProtocolMessageType('TriggerActionConfig', (_message.Message,), dict(

  TriggerAction = _reflection.GeneratedProtocolMessageType('TriggerAction', (_message.Message,), dict(
    DESCRIPTOR = _TRIGGERACTIONCONFIG_TRIGGERACTION,
    __module__ = 'action_pb2'
    # @@protoc_insertion_point(class_scope:action.TriggerActionConfig.TriggerAction)
    ))
  ,
  DESCRIPTOR = _TRIGGERACTIONCONFIG,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.TriggerActionConfig)
  ))
_sym_db.RegisterMessage(TriggerActionConfig)
_sym_db.RegisterMessage(TriggerActionConfig.TriggerAction)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'action_pb2'
  # @@protoc_insertion_point(class_scope:action.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None

_TRIGGERACTION = _descriptor.ServiceDescriptor(
  name='TriggerAction',
  full_name='action.TriggerAction',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2833,
  serialized_end=3061,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='action.TriggerAction.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='action.TriggerAction.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='action.TriggerAction.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIGGERACTION)

DESCRIPTOR.services_by_name['TriggerAction'] = _TRIGGERACTION

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import face_pb2 as face__pb2


class FaceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Scan = channel.unary_unary(
        '/face.Face/Scan',
        request_serializer=face__pb2.ScanRequest.SerializeToString,
        response_deserializer=face__pb2.ScanResponse.FromString,
        )
    self.Extract = channel.unary_unary(
        '/face.Face/Extract',
        request_serializer=face__pb2.ExtractRequest.SerializeToString,
        response_deserializer=face__pb2.ExtractResponse.FromString,
        )
    self.Normalize = channel.unary_unary(
        '/face.Face/Normalize',
        request_serializer=face__pb2.NormalizeRequest.SerializeToString,
        response_deserializer=face__pb2.NormalizeResponse.FromString,
        )
    self.GetConfig = channel.unary_unary(
        '/face.Face/GetConfig',
        request_serializer=face__pb2.GetConfigRequest.SerializeToString,
        response_deserializer=face__pb2.GetConfigResponse.FromString,
        )
    self.SetConfig = channel.unary_unary(
        '/face.Face/SetConfig',
        request_serializer=face__pb2.SetConfigRequest.SerializeToString,
        response_deserializer=face__pb2.SetConfigResponse.FromString,
        )
    self.SetConfigMulti = channel.unary_unary(
        '/face.Face/SetConfigMulti',
        request_serializer=face__pb2.SetConfigMultiRequest.SerializeToString,
        response_deserializer=face__pb2.SetConfigMultiResponse.FromString,
        )
    self.GetAuthGroup = channel.unary_unary(
        '/face.Face/GetAuthGroup',
        request_serializer=face__pb2.GetAuthGroupRequest.SerializeToString,
        response_deserializer=face__pb2.GetAuthGroupResponse.FromString,
        )
    self.AddAuthGroup = channel.unary_unary(
        '/face.Face/AddAuthGroup',
        request_serializer=face__pb2.AddAuthGroupRequest.SerializeToString,
        response_deserializer=face__pb2.AddAuthGroupResponse.FromString,
        )
    self.AddAuthGroupMulti = channel.unary_unary(
        '/face.Face/AddAuthGroupMulti',
        request_serializer=face__pb2.AddAuthGroupMultiRequest.SerializeToString,
        response_deserializer=face__pb2.AddAuthGroupMultiResponse.FromString,
        )
    self.DeleteAuthGroup = channel.unary_unary(
        '/face.Face/DeleteAuthGroup',
        request_serializer=face__pb2.DeleteAuthGroupRequest.SerializeToString,
        response_deserializer=face__pb2.DeleteAuthGroupResponse.FromString,
        )
    self.DeleteAuthGroupMulti = channel.unary_unary(
        '/face.Face/DeleteAuthGroupMulti',
        request_serializer=face__pb2.DeleteAuthGroupMultiRequest.SerializeToString,
        response_deserializer=face__pb2.DeleteAuthGroupMultiResponse.FromString,
        )
    self.DeleteAllAuthGroup = channel.unary_unary(
        '/face.Face/DeleteAllAuthGroup',
        request_serializer=face__pb2.DeleteAllAuthGroupRequest.SerializeToString,
        response_deserializer=face__pb2.DeleteAllAuthGroupResponse.FromString,
        )
    self.DeleteAllAuthGroupMulti = channel.unary_unary(
        '/face.Face/DeleteAllAuthGroupMulti',
        request_serializer=face__pb2.DeleteAllAuthGroupMultiRequest.SerializeToString,
        response_deserializer=face__pb2.DeleteAllAuthGroupMultiResponse.FromString,
        )


class FaceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Scan(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Extract(self, request, context):
    """F2 only
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Normalize(self, request, context):
    """F2 only
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAuthGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddAuthGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddAuthGroupMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAuthGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAuthGroupMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllAuthGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllAuthGroupMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FaceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Scan': grpc.unary_unary_rpc_method_handler(
          servicer.Scan,
          request_deserializer=face__pb2.ScanRequest.FromString,
          response_serializer=face__pb2.ScanResponse.SerializeToString,
      ),
      'Extract': grpc.unary_unary_rpc_method_handler(
          servicer.Extract,
          request_deserializer=face__pb2.ExtractRequest.FromString,
          response_serializer=face__pb2.ExtractResponse.SerializeToString,
      ),
      'Normalize': grpc.unary_unary_rpc_method_handler(
          servicer.Normalize,
          request_deserializer=face__pb2.NormalizeRequest.FromString,
          response_serializer=face__pb2.NormalizeResponse.SerializeToString,
      ),
      'GetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfig,
          request_deserializer=face__pb2.GetConfigRequest.FromString,
          response_serializer=face__pb2.GetConfigResponse.SerializeToString,
      ),
      'SetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfig,
          request_deserializer=face__pb2.SetConfigRequest.FromString,
          response_serializer=face__pb2.SetConfigResponse.SerializeToString,
      ),
      'SetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfigMulti,
          request_deserializer=face__pb2.SetConfigMultiRequest.FromString,
          response_serializer=face__pb2.SetConfigMultiResponse.SerializeToString,
      ),
      'GetAuthGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetAuthGroup,
          request_deserializer=face__pb2.GetAuthGroupRequest.FromString,
          response_serializer=face__pb2.GetAuthGroupResponse.SerializeToString,
      ),
      'AddAuthGroup': grpc.unary_unary_rpc_method_handler(
          servicer.AddAuthGroup,
          request_deserializer=face__pb2.AddAuthGroupRequest.FromString,
          response_serializer=face__pb2.AddAuthGroupResponse.SerializeToString,
      ),
      'AddAuthGroupMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddAuthGroupMulti,
          request_deserializer=face__pb2.AddAuthGroupMultiRequest.FromString,
          response_serializer=face__pb2.AddAuthGroupMultiResponse.SerializeToString,
      ),
      'DeleteAuthGroup': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAuthGroup,
          request_deserializer=face__pb2.DeleteAuthGroupRequest.FromString,
          response_serializer=face__pb2.DeleteAuthGroupResponse.SerializeToString,
      ),
      'DeleteAuthGroupMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAuthGroupMulti,
          request_deserializer=face__pb2.DeleteAuthGroupMultiRequest.FromString,
          response_serializer=face__pb2.DeleteAuthGroupMultiResponse.SerializeToString,
      ),
      'DeleteAllAuthGroup': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllAuthGroup,
          request_deserializer=face__pb2.DeleteAllAuthGroupRequest.FromString,
          response_serializer=face__pb2.DeleteAllAuthGroupResponse.SerializeToString,
      ),
      'DeleteAllAuthGroupMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllAuthGroupMulti,
          request_deserializer=face__pb2.DeleteAllAuthGroupMultiRequest.FromString,
          response_serializer=face__pb2.DeleteAllAuthGroupMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'face.Face', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import timed_apb_zone_pb2 as timed__apb__zone__pb2


class TimedAPBZoneStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/Get',
        request_serializer=timed__apb__zone__pb2.GetRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.GetResponse.FromString,
        )
    self.GetStatus = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/GetStatus',
        request_serializer=timed__apb__zone__pb2.GetStatusRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.GetStatusResponse.FromString,
        )
    self.Add = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/Add',
        request_serializer=timed__apb__zone__pb2.AddRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.AddResponse.FromString,
        )
    self.Clear = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/Clear',
        request_serializer=timed__apb__zone__pb2.ClearRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.ClearResponse.FromString,
        )
    self.ClearAll = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/ClearAll',
        request_serializer=timed__apb__zone__pb2.ClearAllRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.ClearAllResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/Delete',
        request_serializer=timed__apb__zone__pb2.DeleteRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.DeleteResponse.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/DeleteAll',
        request_serializer=timed__apb__zone__pb2.DeleteAllRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.DeleteAllResponse.FromString,
        )
    self.SetAlarm = channel.unary_unary(
        '/timed_apb_zone.TimedAPBZone/SetAlarm',
        request_serializer=timed__apb__zone__pb2.SetAlarmRequest.SerializeToString,
        response_deserializer=timed__apb__zone__pb2.SetAlarmResponse.FromString,
        )


class TimedAPBZoneServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Add(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Clear(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ClearAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAlarm(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TimedAPBZoneServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=timed__apb__zone__pb2.GetRequest.FromString,
          response_serializer=timed__apb__zone__pb2.GetResponse.SerializeToString,
      ),
      'GetStatus': grpc.unary_unary_rpc_method_handler(
          servicer.GetStatus,
          request_deserializer=timed__apb__zone__pb2.GetStatusRequest.FromString,
          response_serializer=timed__apb__zone__pb2.GetStatusResponse.SerializeToString,
      ),
      'Add': grpc.unary_unary_rpc_method_handler(
          servicer.Add,
          request_deserializer=timed__apb__zone__pb2.AddRequest.FromString,
          response_serializer=timed__apb__zone__pb2.AddResponse.SerializeToString,
      ),
      'Clear': grpc.unary_unary_rpc_method_handler(
          servicer.Clear,
          request_deserializer=timed__apb__zone__pb2.ClearRequest.FromString,
          response_serializer=timed__apb__zone__pb2.ClearResponse.SerializeToString,
      ),
      'ClearAll': grpc.unary_unary_rpc_method_handler(
          servicer.ClearAll,
          request_deserializer=timed__apb__zone__pb2.ClearAllRequest.FromString,
          response_serializer=timed__apb__zone__pb2.ClearAllResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=timed__apb__zone__pb2.DeleteRequest.FromString,
          response_serializer=timed__apb__zone__pb2.DeleteResponse.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=timed__apb__zone__pb2.DeleteAllRequest.FromString,
          response_serializer=timed__apb__zone__pb2.DeleteAllResponse.SerializeToString,
      ),
      'SetAlarm': grpc.unary_unary_rpc_method_handler(
          servicer.SetAlarm,
          request_deserializer=timed__apb__zone__pb2.SetAlarmRequest.FromString,
          response_serializer=timed__apb__zone__pb2.SetAlarmResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'timed_apb_zone.TimedAPBZone', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from setuptools import setup, find_packages
import pathlib

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name='biostarPython',
    version='0.1.9.0',
    author_email = 'gcartlidge@supremainc.com',
    author = 'SupremaUK',
    description = 'Python client for Suprema GSDK with included callable classes.',
    long_description=README,
    long_description_content_type="text/markdown",
    url = 'https://github.com/gcartlidge/biostarPython',
    packages=['biostarPython','biostarPython.service','biostarPython.proto'],
    python_requires='>3.5.2',
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
    ],
    package_data={
        "": ["*.py", "*.proto", "*.json"],
        "proto": ["*.proto"],
        "service": ["*.py"],
    },
    install_requires=[
        'grpcio',
        'protobuf<4',
    ],
)